@@ -1,5 +1,5 @@
 package App::Oozie::Deploy::Template;
-$App::Oozie::Deploy::Template::VERSION = '0.006';
+$App::Oozie::Deploy::Template::VERSION = '0.007';
 use 5.010;
 use strict;
 use warnings;
@@ -182,7 +182,6 @@ sub compile {
     # Possible improvement: use libraries instead of this command
     #     if feasible
     my @command = (
-        'ttree',
         '-f'     => $tt_conf_file,
         '-a',
         '--src'  => $workflow,
@@ -227,11 +226,7 @@ sub compile {
         }
     }
 
-    my( $ok, $err, $full_buf, $stdout_buff, $stderr_buff ) = IPC::Cmd::run(
-        command => \@command,
-        verbose => $self->verbose,
-        timeout => $self->timeout,
-    );
+    my($ok, $err, $full_buf, $stdout_buff, $stderr_buff) = $self->_ttree_cli( @command );
 
     # ttree doesn't return an error status when it encounters an error, so just
     # look at the output
@@ -283,6 +278,55 @@ sub compile {
     ;
 }
 
+sub _ttree_obj {
+    my $self = shift;
+    my @command = @_;
+    require App::Oozie::Deploy::Template::ttree;
+
+    my( $ok, $err, $full_buf, $stdout_buff, $stderr_buff );
+
+    $stdout_buff = [];
+    $stderr_buff = [];
+
+    my $logger = sub {
+        my %log = @_;
+        if ( $log{level} eq 'info' ) {
+            push @{ $stdout_buff }, $log{msg};
+        }
+        else {
+            push @{ $stderr_buff }, $log{msg};
+        }
+    };
+
+    eval {
+        my $ttree = App::Oozie::Deploy::Template::ttree->new( $logger );
+        $ttree->run( @command );
+        $ok = 1;
+        1;
+    } or do {
+        my $eval_error = $@ || 'Zombie error';
+        push @{ $stderr_buff }, $eval_error;
+    };
+
+    $full_buf = [ @{ $stdout_buff }, @{ $stderr_buff } ];
+
+    return ( $ok, $err, $full_buf, $stdout_buff, $stderr_buff );
+}
+
+sub _ttree_cli {
+    my $self = shift;
+    my @command = @_;
+
+    unshift @command, 'ttree';
+
+    my( $ok, $err, $full_buf, $stdout_buff, $stderr_buff ) = IPC::Cmd::run(
+        command => \@command,
+        verbose => $self->verbose,
+        timeout => $self->timeout,
+    );
+    return $ok, $err, $full_buf, $stdout_buff, $stderr_buff;
+}
+
 sub _probe_readme {
     my $self                  = shift;
     my $workflow              = shift;
@@ -510,7 +554,7 @@ App::Oozie::Deploy::Template
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
